@@ -28,15 +28,6 @@ G_BEGIN_DECLS
 /* For information look into the C source or the html documentation */
 
 
-#ifndef GIMP_DISABLE_DEPRECATED
-/*
- * GIMP_MODULE_PARAM_SERIALIZE is deprecated, use
- * GIMP_CONFIG_PARAM_SERIALIZE instead.
- */
-#define GIMP_MODULE_PARAM_SERIALIZE (1 << (0 + G_PARAM_USER_SHIFT))
-#endif
-
-
 typedef struct _GimpModule     GimpModule;
 typedef struct _GimpModuleInfo GimpModuleInfo;
 typedef struct _GimpModuleDB   GimpModuleDB;
